All of lore.kernel.org
 help / color / mirror / Atom feed
From: John McNamara <john.mcnamara@intel.com>
To: dev@dpdk.org
Subject: [PATCH v3 1/2] version: switch to year/month version numbers
Date: Wed, 10 Feb 2016 17:02:11 +0000	[thread overview]
Message-ID: <1455123732-1705-1-git-send-email-john.mcnamara@intel.com> (raw)
In-Reply-To: <1450704384-9986-1-git-send-email-bruce.richardson@intel.com>

From: "Richardson, Bruce" <bruce.richardson@intel.com>

As discussed on list, switch numbering scheme to be based on year/month.
Release 2.3 then becomes 16.04.

    Ref: http://dpdk.org/ml/archives/dev/2015-December/030336.html

Also, added zero padding to the month so that it appear as 16.04 and
not 16.4 in "make showversion" and rte_version().

Signed-off-by: Bruce Richardson <bruce.richardson@intel.com>
Signed-off-by: John McNamara <john.mcnamara@intel.com>
---
 drivers/net/nfp/nfp_net.c                   |  2 --
 lib/librte_eal/common/include/rte_version.h | 42 ++++++++++++++---------------
 mk/rte.sdkconfig.mk                         |  2 +-
 3 files changed, 22 insertions(+), 24 deletions(-)

diff --git a/drivers/net/nfp/nfp_net.c b/drivers/net/nfp/nfp_net.c
index ffa5730..fd4dd39 100644
--- a/drivers/net/nfp/nfp_net.c
+++ b/drivers/net/nfp/nfp_net.c
@@ -1070,9 +1070,7 @@ nfp_net_infos_get(struct rte_eth_dev *dev, struct rte_eth_dev_info *dev_info)
 	};
 
 	dev_info->reta_size = NFP_NET_CFG_RSS_ITBL_SZ;
-#if RTE_VER_MAJOR == 2 && RTE_VER_MINOR >= 1
 	dev_info->hash_key_size = NFP_NET_CFG_RSS_KEY_SZ;
-#endif
 }
 
 static uint32_t
diff --git a/mk/rte.sdkconfig.mk b/mk/rte.sdkconfig.mk
index f8d95b1..564a5c3 100644
--- a/mk/rte.sdkconfig.mk
+++ b/mk/rte.sdkconfig.mk
@@ -35,7 +35,7 @@ showversion:
 		$$(sed -rne 's,^#define RTE_VER_[A-Z_]*[[:space:]]+([0-9]+).*,\1,p' \
 			-e 's,^#define RTE_VER_SUFFIX[[:space:]]+"(.*)",\1,p' \
 			$(RTE_SRCDIR)/lib/librte_eal/common/include/rte_version.h) ;\
-		printf '%d.%d.%d' "$$1" "$$2" "$$3"; \
+		printf '%d.%02d.%d' "$$1" "$$2" "$$3"; \
 		if [ -z "$$5" ]; then echo; \
 		else printf '%s' "$$4"; \
 			if [ $$5 -lt 16 ] ; then echo $$5; \
diff --git a/lib/librte_eal/common/include/rte_version.h b/lib/librte_eal/common/include/rte_version.h
index 0baf130..779f17f 100644
--- a/lib/librte_eal/common/include/rte_version.h
+++ b/lib/librte_eal/common/include/rte_version.h
@@ -50,22 +50,22 @@ extern "C" {
 /**
  * String that appears before the version number
  */
-#define RTE_VER_PREFIX "RTE"
+#define RTE_VER_PREFIX "DPDK"
 
 /**
  * Major version number i.e. the x in x.y.z
  */
-#define RTE_VER_MAJOR 2
+#define RTE_VER_YEAR 16
 
 /**
  * Minor version number i.e. the y in x.y.z
  */
-#define RTE_VER_MINOR 3
+#define RTE_VER_MONTH 4
 
 /**
- * Patch level number i.e. the z in x.y.z
+ * Patch level number i.e. the z in yy.mm.z
  */
-#define RTE_VER_PATCH_LEVEL 0
+#define RTE_VER_MINOR 0
 
 /**
  * Extra string to be appended to version number
@@ -77,7 +77,7 @@ extern "C" {
  *   0-15 = release candidates
  *   16   = release
  */
-#define RTE_VER_PATCH_RELEASE 0
+#define RTE_VER_RELEASE 0
 
 /**
  * Macro to compute a version number usable for comparisons
@@ -88,10 +88,10 @@ extern "C" {
  * All version numbers in one to compare with RTE_VERSION_NUM()
  */
 #define RTE_VERSION RTE_VERSION_NUM( \
-			RTE_VER_MAJOR, \
+			RTE_VER_YEAR, \
+			RTE_VER_MONTH, \
 			RTE_VER_MINOR, \
-			RTE_VER_PATCH_LEVEL, \
-			RTE_VER_PATCH_RELEASE)
+			RTE_VER_RELEASE)
 
 /**
  * Function returning version string
@@ -105,21 +105,21 @@ rte_version(void)
 	if (version[0] != 0)
 		return version;
 	if (strlen(RTE_VER_SUFFIX) == 0)
-		snprintf(version, sizeof(version), "%s %d.%d.%d",
+		snprintf(version, sizeof(version), "%s %d.%02d.%d",
 			RTE_VER_PREFIX,
-			RTE_VER_MAJOR,
-			RTE_VER_MINOR,
-			RTE_VER_PATCH_LEVEL);
+			RTE_VER_YEAR,
+			RTE_VER_MONTH,
+			RTE_VER_MINOR);
 	else
-		snprintf(version, sizeof(version), "%s %d.%d.%d%s%d",
+		snprintf(version, sizeof(version), "%s %d.%02d.%d%s%d",
 			RTE_VER_PREFIX,
-			RTE_VER_MAJOR,
+			RTE_VER_YEAR,
+			RTE_VER_MONTH,
 			RTE_VER_MINOR,
-			RTE_VER_PATCH_LEVEL,
 			RTE_VER_SUFFIX,
-			RTE_VER_PATCH_RELEASE < 16 ?
-				RTE_VER_PATCH_RELEASE :
-				RTE_VER_PATCH_RELEASE - 16);
+			RTE_VER_RELEASE < 16 ?
+				RTE_VER_RELEASE :
+				RTE_VER_RELEASE - 16);
 	return version;
 }
 
@@ -50,22 +50,22 @@ extern "C" {
 
 /**
- * Major version number i.e. the x in x.y.z
+ * Major version/year number i.e. the yy in yy.mm.z
  */
@@ -50,22 +50,22 @@ extern "C" {
 
 /**
- * Minor version number i.e. the y in x.y.z
+ * Minor version/month number i.e. the mm in yy.mm.z
  */
-- 
2.5.0

  parent reply	other threads:[~2016-02-10 17:03 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2015-12-21 13:26 [PATCH 0/3] switch to using YY.MM version numbers Bruce Richardson
2015-12-21 13:26 ` [PATCH 1/3] version: switch to year/month " Bruce Richardson
2016-02-10 14:33   ` [PATCH v2 1/2] " John McNamara
2016-02-10 14:33     ` [PATCH v2 2/2] doc: rename release notes 2.3 to 16.04 John McNamara
2016-02-10 15:11     ` [PATCH v2 1/2] version: switch to year/month version numbers Thomas Monjalon
2016-02-10 15:31       ` Bruce Richardson
2016-02-10 16:52       ` Mcnamara, John
2015-12-21 13:26 ` [PATCH 2/3] version: adjust printing for new version scheme Bruce Richardson
2015-12-28 22:25   ` Thomas Monjalon
2016-02-10 14:28     ` Mcnamara, John
2015-12-21 13:26 ` [PATCH 3/3] doc: rename release 2.3 to 16.04 Bruce Richardson
2016-02-10 17:02 ` John McNamara [this message]
2016-02-10 17:02   ` [PATCH v3 2/2] doc: rename release notes " John McNamara
2016-02-10 17:11   ` [PATCH v3 1/2] version: switch to year/month version numbers Mcnamara, John
2016-02-10 17:20     ` Thomas Monjalon
2016-02-10 21:49   ` Thomas Monjalon

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1455123732-1705-1-git-send-email-john.mcnamara@intel.com \
    --to=john.mcnamara@intel.com \
    --cc=dev@dpdk.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.